pub struct SymbolData {
pub symbol: String,
pub price: f64,
pub technical_analysis: f64,
}Expand description
The data related to a particular symbol
Arguments
symbol: The specified symbol that data is being collected for, in formatMARKET:SYMBOLe.g.,NYSE:AAPLprice: A tokio mpsc sender stream, used for sending messages to the servertechnical_analysis: The current data from the datastream about prices and technical analysis, set by either ‘set_data_price’ or ‘set_data_ta’
Fields
symbol: Stringprice: f64technical_analysis: f64Trait Implementations
Sourceimpl Clone for SymbolData
impl Clone for SymbolData
Sourcefn clone(&self) -> SymbolData
fn clone(&self) -> SymbolData
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for SymbolData
impl RefUnwindSafe for SymbolData
impl Send for SymbolData
impl Sync for SymbolData
impl Unpin for SymbolData
impl UnwindSafe for SymbolData